aboutsummaryrefslogtreecommitdiffstats
path: root/src/gamma-x-vidmode.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/gamma-x-vidmode.h (renamed from src/gamma-randr.h)82
1 files changed, 41 insertions, 41 deletions
diff --git a/src/gamma-randr.h b/src/gamma-x-vidmode.h
index 7d0ba9e..670e06d 100644
--- a/src/gamma-randr.h
+++ b/src/gamma-x-vidmode.h
@@ -15,12 +15,12 @@
* You should have received a copy of the GNU General Public License
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef LIBGAMMA_GAMMA_RANDR_H
#define LIBGAMMA_GAMMA_RANDR_H
#ifndef HAVE_GAMMA_METHOD_RANDR
# error Including gamma-randr.h without HAVE_GAMMA_METHOD_RANDR
#endif
@@ -32,7 +32,7 @@
*
* @param this The data structure to fill with the method's capabilities
*/
-void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict this);
+void libgamma_x_vidmode_method_capabilities(libgamma_method_capabilities_t* restrict this);
/**
* Initialise an allocated site state
@@ -47,15 +47,15 @@ void libgamma_randr_method_capabilities(libgamma_method_capabilities_t* restrict
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_initialise(libgamma_site_state_t* restrict this,
- char* restrict site);
+int libgamma_x_vidmode_site_initialise(libgamma_site_state_t* restrict this,
+ char* restrict site);
/**
* Release all resources held by a site state
*
* @param this The site state
*/
-void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this);
+void libgamma_x_vidmode_site_destroy(libgamma_site_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a site to the system settings
@@ -64,7 +64,7 @@ void libgamma_randr_site_destroy(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_site_restore(libgamma_site_state_t* restrict this);
+int libgamma_x_vidmode_site_restore(libgamma_site_state_t* restrict this);
/**
@@ -76,15 +76,15 @@ int libgamma_randr_site_restore(libgamma_site_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_initialise(libgamma_partition_state_t* restrict this,
- libgamma_site_state_t* restrict site, size_t partition);
+int libgamma_x_vidmode_partition_initialise(libgamma_partition_state_t* restrict this,
+ libgamma_site_state_t* restrict site, size_t partition);
/**
* Release all resources held by a partition state
*
* @param this The partition state
*/
-void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this);
+void libgamma_x_vidmode_partition_destroy(libgamma_partition_state_t* restrict this);
/**
* Release all resources held by a partition state
@@ -92,7 +92,7 @@ void libgamma_randr_partition_destroy(libgamma_partition_state_t* restrict this)
*
* @param this The partition state
*/
-void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this);
+void libgamma_x_vidmode_partition_free(libgamma_partition_state_t* restrict this);
/**
* Restore the gamma ramps all CRTCS with a partition to the system settings
@@ -101,7 +101,7 @@ void libgamma_randr_partition_free(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this);
+int libgamma_x_vidmode_partition_restore(libgamma_partition_state_t* restrict this);
/**
@@ -113,15 +113,15 @@ int libgamma_randr_partition_restore(libgamma_partition_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_initialise(libgamma_crtc_state_t* restrict this,
- libgamma_partition_state_t* restrict partition, size_t crtc);
+int libgamma_x_vidmode_crtc_initialise(libgamma_crtc_state_t* restrict this,
+ libgamma_partition_state_t* restrict partition, size_t crtc);
/**
* Release all resources held by a CRTC state
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
+void libgamma_x_vidmode_crtc_destroy(libgamma_crtc_state_t* restrict this);
/**
* Release all resources held by a CRTC state
@@ -129,7 +129,7 @@ void libgamma_randr_crtc_destroy(libgamma_crtc_state_t* restrict this);
*
* @param this The CRTC state
*/
-void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this);
+void libgamma_x_vidmode_crtc_free(libgamma_crtc_state_t* restrict this);
/**
* Restore the gamma ramps for a CRTC to the system settings for that CRTC
@@ -138,7 +138,7 @@ void libgamma_randr_crtc_free(libgamma_crtc_state_t* restrict this);
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
+int libgamma_x_vidmode_crtc_restore(libgamma_crtc_state_t* restrict this);
/**
@@ -149,8 +149,8 @@ int libgamma_randr_crtc_restore(libgamma_crtc_state_t* restrict this);
* @param fields OR:ed identifiers for the information about the CRTC that should be read
* @return Zero on success, -1 on error. On error refer to the error reports in `this`.
*/
-int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict this,
- libgamma_crtc_state_t* restrict crtc, int32_t fields);
+int libgamma_x_vidmode_get_crtc_information(libgamma_crtc_information_t* restrict this,
+ libgamma_crtc_state_t* restrict crtc, int32_t fields);
/**
* Get current the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -160,8 +160,8 @@ int libgamma_randr_get_crtc_information(libgamma_crtc_information_t* restrict th
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 16-bit gamma-depth version
@@ -171,8 +171,8 @@ int libgamma_randr_crtc_get_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps_t ramps);
/**
@@ -183,8 +183,8 @@ int libgamma_randr_crtc_set_gamma_ramps(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 32-bit gamma-depth version
@@ -194,8 +194,8 @@ int libgamma_randr_crtc_get_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps32_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps32_t ramps);
/**
@@ -206,8 +206,8 @@ int libgamma_randr_crtc_set_gamma_ramps32(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, 64-bit gamma-depth version
@@ -217,8 +217,8 @@ int libgamma_randr_crtc_get_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_ramps64_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_ramps64_t ramps);
/**
@@ -229,8 +229,8 @@ int libgamma_randr_crtc_set_gamma_ramps64(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `float` version
@@ -240,8 +240,8 @@ int libgamma_randr_crtc_get_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsf_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsf_t ramps);
/**
* Get current the gamma ramps for a CRTC, `double` version
@@ -251,8 +251,8 @@ int libgamma_randr_crtc_set_gamma_rampsf(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t* restrict ramps);
+int libgamma_x_vidmode_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t* restrict ramps);
/**
* Set the gamma ramps for a CRTC, `double` version
@@ -262,8 +262,8 @@ int libgamma_randr_crtc_get_gamma_rampsd(libgamma_crtc_state_t* restrict this,
* @return Zero on success, otherwise (negative) the value of an
* error identifier provided by this library
*/
-int libgamma_randr_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
- libgamma_gamma_rampsd_t ramps);
+int libgamma_x_vidmode_crtc_set_gamma_rampsd(libgamma_crtc_state_t* restrict this,
+ libgamma_gamma_rampsd_t ramps);
#endif
@@ -15,12 +15,12 @@
* along with this library. If not, see <http://www.gnu.org/licenses/>.
*/
-#ifndef LIBGAMMA_GAMMA_RANDR_H
-#define LIBGAMMA_GAMMA_RANDR_H
+#ifndef LIBGAMMA_GAMMA_X_VIDMODE_H
+#define LIBGAMMA_GAMMA_X_VIDMODE_H
-#ifndef HAVE_GAMMA_METHOD_RANDR
-# error Including gamma-randr.h without HAVE_GAMMA_METHOD_RANDR
+#ifndef HAVE_GAMMA_METHOD_X_VIDMODE
+# error Including gamma-x-vidmode.h without HAVE_GAMMA_METHOD_X_VIDMODE
#endif